@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2010-2016 Innocent De Marchi <tangram.peces@gmail.com>
+ * Copyright (C) 2010-2017 Innocent De Marchi <tangram.peces@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ Fitxa::Fitxa(Tauler*  taulerJoc, QGraphicsItem* parent)
     p_nivellAillament=0;
     p_fitxaFinalJoc=false;
     p_fitxaUsadaGeneracioSolitariAtzar=false;
+    p_numConjunt=0;
     setFitxaSolitariPersonalitzat(false);
 }
 
@@ -60,43 +61,53 @@ void Fitxa::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,  QW
  }
  else painter->setPen( Qt::NoPen );
 
+//
+
  switch (m_estat) {
     // case -1: //lloc buit sense dibuixar
     //   painter->setPen( Qt::red);
      case 0: // Lloc buit
        painter->setBrush(gradientRadial);
+       painter->drawEllipse(1,1,30,30);
       // painter->setPen( Qt::NoPen );
        break;
      case 1:  //estat normal de la fitxa
        painter->setBrush(gradientLinear);
+       painter->drawEllipse(1,1,30,30);
       // painter->setPen( Qt::blue );
        break;
      case 2: //Fitxa Seleccionada per a un moviment
        gradientLinear.setColorAt(1, QColor(Qt::yellow));
        painter->setBrush(gradientLinear);
+       painter->drawEllipse(1,1,30,30);
       // painter->setPen( Qt::NoPen );
        break;
      case 3: //destí d'un moviment
        painter->setBrush(gradientRadial);
        painter->setPen(QPen(Qt::red,3));
+       painter->drawEllipse(1,1,30,30);
        break;
      case 4: //Fitxa al final de joc resolt
        gradientLinear.setColorAt(1, QColor(Qt::green));
        painter->setBrush(gradientLinear);
+       painter->drawEllipse(1,1,30,30);
       // painter->setPen( Qt::NoPen );
        break;
      case 5: //El joc s'ha acabat ja que no hi ha més moviments
-       gradientLinear.setColorAt(1, QColor(Qt::red));
-       painter->setBrush(gradientLinear);
+         gradientLinear.setColorAt(1, QColor(Qt::red));
+         painter->setBrush(gradientLinear);
+         painter->drawEllipse(1,1,30,30);
      //  painter->setPen( Qt::NoPen );
        break;
      case 6: //Lloc disponible per posar fitxes (joc personalitzat)
-         gradientLinear.setColorAt(1, QColor(Qt::black));
-         //painter->setBrush(gradientLinear);
+         gradientLinear.setColorAt(1, QColor(Qt::black));         
+         painter->setBrush(Qt::NoBrush);
+         painter->setPen( Qt::black );
+         painter->drawRect(1,1,30,30);
          break;
      default: //estat normal de la fitxa
        painter->setPen( Qt::blue );
-
+       painter->drawEllipse(1,1,30,30);
  }
  /*
  if (p_esMou){
@@ -104,21 +115,72 @@ void Fitxa::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,  QW
  }
  */
 
-/*
  if (p_aillada){
-    painter->setBrush(Qt::black );
- }
- */
-
-
- if (m_estat==6){
-   painter->setBrush(Qt::NoBrush);
-   painter->setPen( Qt::black );
-   painter->drawRect(1,1,30,30);}
- else{
-   painter->drawEllipse(1,1,30,30);
+    painter->setBrush(Qt::magenta);
  }
 
+
+
+// if(p_numConjunt>0){
+
+//   if(p_numConjunt==1){
+//     painter->setPen( Qt::blue );
+//     painter->setBrush(Qt::blue);
+//     if(p_distanciaAillament>1){
+//       painter->setPen( Qt::darkBlue );
+//       painter->setBrush(Qt::darkBlue);
+//     }
+//     painter->drawEllipse(1,1,30,30);
+//    }
+//   else if(p_numConjunt==2){
+//     painter->setPen(Qt::yellow);
+//     painter->setBrush(Qt::yellow);
+//     if(p_distanciaAillament>1){
+//       painter->setPen(Qt::darkYellow);
+//       painter->setBrush(Qt::darkYellow);
+//     }
+//     painter->drawEllipse(1,1,30,30);
+//   }
+//   else if(p_numConjunt==3){
+//     painter->setPen(Qt::green);
+//     painter->setBrush(Qt::green);
+//     if(p_distanciaAillament>1){
+//       painter->setPen(Qt::darkGreen);
+//       painter->setBrush(Qt::darkGreen);
+//     }
+//     painter->drawEllipse(1,1,30,30);
+//   }
+//   else if(p_numConjunt==4){
+//       painter->setPen(Qt::cyan);
+//     painter->setBrush(Qt::cyan);
+//     if(p_distanciaAillament>1){
+//         painter->setPen(Qt::darkCyan);
+//       painter->setBrush(Qt::darkCyan);
+//     }
+//     painter->drawEllipse(1,1,30,30);
+//   }
+//   else if(p_numConjunt==5){
+//       painter->setPen(Qt::gray);
+//     painter->setBrush(Qt::gray);
+//     if(p_distanciaAillament>1){
+//       painter->setPen(Qt::darkGray);
+//       painter->setBrush(Qt::darkGray);
+//     }
+//     painter->drawEllipse(1,1,30,30);
+//   }
+
+//   painter->setPen( Qt::black );
+////   painter->drawText(QPoint(5,10),QString("%1 %2").arg(p_numConjunt).arg(p_distanciaAillament));
+//   painter->drawText(QPoint(5,10),QString("%1 %2").arg(p_numConjunt).arg(p_distanciaAillamentConjunt));
+// }
+
+// if (m_estat==6){
+//   painter->setBrush(Qt::NoBrush);
+//   painter->setPen( Qt::black );
+//   painter->drawRect(1,1,30,30);}
+// else{
+//   painter->drawEllipse(1,1,30,30);
+// }
 }
 
 void Fitxa::mousePressEvent(QGraphicsSceneMouseEvent* event) {
@@ -372,7 +434,7 @@ void Fitxa::setEstat( int nouValor , bool canviarFitxaFinalJoc)
   //com a final de joc en el solitari personalitzat
  // if( (m_estat != nouValor) || (nouValor==0) ){
       m_estat = nouValor;
-     //Si la fitxa es "mou", llavors reinciam l'aïllament
+     //Si la fitxa es "mou", llavors reiniciam l'aïllament
      if(m_estat==0) {setFitxaAillada(false);}
      update();//}
 }
@@ -400,12 +462,12 @@ void Fitxa::setPreferenciaMoure(int preferencia){
 
 /*
            Controla el tipus de moviment
-           1: moviment directa (l'habitual del joc)
+           1: moviment directe (l'habitual del joc)
            2: moviment invers
            3: moviment en direcció perpendicular i diagonal
            4: proposta de problema
            5: moviment en direcció perpendicular/diagonal i invers
-              (nou per la generació a l'atzar)
+              (nou per a la generació a l'atzar)
            */
 void Fitxa::setTipusMoviment (int nouTipus){
   if( (nouTipus < 0)  || (nouTipus >  5))
@@ -468,3 +530,22 @@ void Fitxa::incrementaNivellAillament(){
     ++p_nivellAillament;
 }
 
+void Fitxa::setConjuntAillament(int numConjunt){
+    p_numConjunt=numConjunt;
+    update();
+}
+
+void Fitxa::setDistanciaAillament(int distancia){
+  if(p_distanciaAillament != distancia){
+    p_distanciaAillament=distancia;
+    update();}
+}
+
+
+void Fitxa::setDistanciaAillamentConjunt(int distancia){
+    if(p_distanciaAillamentConjunt != distancia){
+      p_distanciaAillamentConjunt=distancia;
+//      qDebug("%d", p_distanciaAillamentConjunt);
+      update();
+  }
+}
