@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2010-2016 Innocent De Marchi <tangram.peces@gmail.com>
+ * Copyright (C) 2010-2017 Innocent De Marchi <tangram.peces@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,8 +66,21 @@ int numeroConfiguracio(QString config){
      return numero;
 }
 
-/* fa una pausa en milisegons
-void pausa(int temps){
-  QTest::qSleep(temps);
-  qApp->processEvents();
-}*/
+QString coordenadesAMoviment(QString coordenades){
+  QRegExp coord(".(\\d+),(\\d+). -> .(\\d+),(\\d+).");
+  if (coord.exactMatch(coordenades)){
+      int fitxaBotada=((coord.cap(1).toInt()+coord.cap(3).toInt())/2)*100+
+                      ((coord.cap(2).toInt()+coord.cap(4).toInt())/2);
+      return QString("%1 %2 %3").arg(coord.cap(1).toInt()*100+coord.cap(2).toInt()).
+          arg(fitxaBotada).
+          arg(coord.cap(3).toInt()*100+coord.cap(4).toInt());
+  }
+  else {
+      return   QString("");}
+}
+
+/* fa una pausa en milisegons*/
+//void pausa(int temps){
+//  QTest::qSleep(temps);
+//  qApp->processEvents();
+//}
