@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2010-2016 Innocent De Marchi <tangram.peces@gmail.com>
+ * Copyright (C) 2010-2017 Innocent De Marchi <tangram.peces@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,9 @@
 #include <QTextCodec>
 #include <QLocale>
 #include <QtCore>
+#include <QtWidgets/QSplashScreen>
 #include "frmprincipal.h"
+#include "funcions.h"
 
  QTranslator *qt_translator;
  QTranslator *appTranslator;
@@ -30,7 +32,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
         app.setApplicationName("Solitari");
-        app.setApplicationVersion("2.1");
+        app.setApplicationVersion("2.2");
         app.setOrganizationName("De Marchi");
 
         //Això pels accents a les cadenes
@@ -39,6 +41,11 @@ int main(int argc, char *argv[])
        // QTextCodec::setCodecForCStrings(linuxCodec);
         QTextCodec::setCodecForLocale(linuxCodec);
 
+        QPixmap pixmap(directoriLinux()+QDir().separator()+"images"+QDir().separator()+"asimetric_jugant.png");
+        QSplashScreen splash(pixmap);
+        splash.show();
+        //Sense aquesta línia,la imatge no s'actualitza
+        splash.showMessage("");
 
     //Això per a que surtin traduïdes les cadenes dels formularis predefinits Qt
      QString qt_translatorFileName = QLatin1String("qt_");
@@ -48,7 +55,7 @@ int main(int argc, char *argv[])
      if (qt_translator->load(qt_translatorFileName, QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
          app.installTranslator(qt_translator);
      //15/02/15 A windows cal posar
-     /*if (translator->load(translatorFileName, QApplication::applicationDirPath()))
+     /*if (qt_translator->load(qt_translatorFileName, QApplication::applicationDirPath()))
       app.installTranslator(translator);*/
 
    //Això per les traduccions
@@ -60,5 +67,6 @@ int main(int argc, char *argv[])
     frmPrincipal *frmMDI=new frmPrincipal();
     frmMDI->show();
 
+    splash.finish(frmMDI);
     return app.exec();
 }
